#
# spec file for package rcm
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# See also http://en.opensuse.org/openSUSE:Specfile_guidelines
Name:           rcm
Version:        1.3.6
Release:        1.2
Summary:        An rc file (dotfile) management tool
License:        BSD-3-Clause
Group:          Productivity/File utilities
URL:            https://thoughtbot.github.io/rcm/
Source0:        https://thoughtbot.github.io/rcm/dist/%{name}-%{version}.tar.gz
Requires:       bash
BuildArch:      noarch

%description
The rcm suite of tools is for managing dotfiles directories. This is a
directory containing all the .*rc files in your home directory (.zshrc,
.vimrc, and so on). These files have gone by many names in history,
such as “rc files” because they typically end in rc or “dotfiles”
because they begin with a period.

%prep
%setup -q

%build
%configure

%install
%make_install

mkdir -p '%{buildroot}/%{_docdir}/%{name}'
cp -a LICENSE README.md NEWS.md '%{buildroot}/%{_docdir}/%{name}'

%files
%{_bindir}/*

%{_mandir}/man1/*
%{_mandir}/man5/*
%{_mandir}/man7/*

%{_datadir}/rcm/

%{_docdir}/%{name}

%changelog
* Wed Jan 18 2023 Andrei Dziahel <develop7@develop7.info>
- Update to version 1.3.6
  * Feature: rcup/rcdn hooks can bail early (Patrick Brisbin)
  * Documentation improvement (Teo Ljungberg)
* Mon May  9 2022 Andrei Dziahel <develop7@develop7.info>
- Update to version 1.3.5
  * BUGFIX: *:*~ exclude paterns work again (Alexander Goldstein)
  * BUGFIX: messages for -C being a copy so can't update (Mat M).
  * BUGFIX: expect at least one existing dotfiles directory (Mat M).
  * BUGFIX: fix program name in rcdn -V (Ivan Tkachenko)
  * Feature: mkrc hooks via -k/-K (Patrick Brisbin)
  * Feature: All symlinks in input are rejected (Mat M).
  * Package and maintenance improvements (Alexander Goldstein, Eric Collins,
    Mat M, Darcy Parker).
* Thu Feb 18 2021 Wang Jun <jgwang@suse.com>
- Update to version 1.3.4
  * BUGFIX: Globs no longer expand permanently (Edd Salkield).
  * BUGFIX: Show $ for symlinked dirs in `lsrc -F` (Mathias Michel).
  * Feature: All symlinks in input are rejected (Mat M).
  * Packaging improvements (Stephen Groat, Martin Frost, Link Dupont).
* Sun Jul 15 2018 develop7@develop7.info
- drop source service
- rcm 1.3.3
  * Feature: Expand ~ in DOTFILES_DIR hooks (Eric Collins).
- rcm 1.3.2
  * BUGFIX: Use =, not ==, in test(1) (Florian Tham).
  * BUGFIX: Directories with spaces in rcup(1) (Florian Tham).
  * BUGFIX: Fallback the LOGNAME from whoami (AJ Villalobos, Mike Burns).
  * BUGFIX: Fix cd for paths beginning with hyphen (-) (Christian Höltje).
  * Feature: Expand ~ in DOTFILES_DIR (Rebecca Meritz).
  * Documentation improvements (Alan Yee, Eric Collins, Florian Tham, kajisha,
  Matthew Horan, maxice8, Mike Burns, Rebecca Meritz, Scott Stevenson,
  Tyson Gach, Yota Toyama).
* Wed Mar 21 2018 develop7@develop7.info
- modernized spec with spec-cleaner
* Fri Jan 27 2017 develop7@develop7.info
- introduced package documentation, including LICENSE
* Fri Jan 20 2017 develop7@develop7.info
- disable source service per Factory requirement
* Sat Jan  7 2017 develop7@develop7.info
- Release 1.3.1
  * BUGFIX: Handle dotfile names with spaces in them (Eric Collins, Mike
    Burns).
  * BUGFIX: Relative exclude globs now work (Eric Collins, Mike Burns).
  * BUGFIX: Use $LOGNAME instead of $USER for compatibility (Mike
    Burns).
  * BUGFIX: rcdn(1) stops at DEST_DIR (Kyle Cook, Mike Burns).
  * BUGFIX: Symlink existing files, even when identical (Graham
    Bennett).
  * BUGFIX: Sort hooks by filename before execution instead of
    arbitrary order (David Alexander).
  * Documentation improvements (Nick Novitski, Ben
    Stephens, Casey Rodarmor).
* Sun Dec 13 2015 develop7@develop7.info
- Release 1.3.0
  * BUGFIX: Control whether hooks should run in rcdn(1) with the -K and -k
    flags (Ben Turrubiates, Christopher Koch, Mike Burns, Mikkel Fahnøe
    Jørgensen).
  * Massive documentation fixes and updates (Christopher Koch, David Alexander,
    Jason Daniel Augustine Gilliland, Martin Frost, Melissa Xie, Mike Burns,
    Scott Stevenson, Jarkko Kniivilä, Blake Williams, Carl van Tonder, Teo
    Ljungberg, Zach Latta, Devraj Mehta, Vlad GURDIGA, Joe Ferris).
  * Host-specific files take priority, then tags, then default (Christian
    Höltje).
  * Run hooks in the directory in which they are located (Jarkko Kniivilä).
  * Generate a minimal standalone rcup(1) script with the -g flag (Mike Burns).
  * Support rc files without leading dots via the -U and -u flags in lsrc(1),
    rcup(1), and rcdn(1), and the UNDOTTED setting in rcrc(5) (Christopher
    Koch).
  * Improved Solaris support (Jarkko Kniivilä).
  * Override `SYMLINK_DIRS` or -S with -s (Mike Burns).
  * Show usage information when given bad arguments (Mike Burns).
- Make use of download_files source service
* Sun May 11 2014 develop7@develop7.info
- release 1.2.3
  * BUGFIX: Allow files with the same prefix name in the same
    directory (Javier López).
  * BUGFIX: Pick up hooks that are executable by the user or by the
    group, instead of only files that are 777 (Christian Höltje).
  * Allow running mkrc on a relative file and preserve the
    path (Pablo Olmos de Aguilera Corradini).
  * A flag (-B), and a variable for rcrc(5) (HOSTNAME), for changing the
    hostname as rcm sees it. This is highly recommended under OS X (Mike
    Burns).
  * Transfer copyright to thoughtbot, under the same license (Mike Burns).
* Sat Mar 29 2014 develop7@develop7.info
- release 1.2.2
  * removed rcm-1.2.1-fix-rpmlint-perm-warn.patch since fix had
    landed upstream
* Mon Mar 24 2014 develop7@develop7.info
- fixed rpmlint warning with rcm-1.2.1-fix-rpmlint-perm-warn.patch
* Fri Mar 21 2014 develop7@develop7.info
- release 1.2.1
* Fri Feb 14 2014 develop7@develop7.info
- rcm 1.2.0 release
